@@ -977,36 +977,57 @@ class Dominus:
             system=system
         )
 
-    async def get_public_key(self) -> str:
-        """Get Sovereign's public key for JWT validation (cached)."""
+    async def get_public_key(self) -> Dict[str, Any]:
+        """Get Sovereign's JWKS for JWT validation (cached)."""
         if self._public_key_cache:
             return self._public_key_cache
 
         result = await self._execute("auth.jwks")
-        self._public_key_cache = result.get("public_key")
+        self._public_key_cache = result
         return self._public_key_cache
 
     async def validate_jwt(self, token: str) -> Dict[str, Any]:
         """
         Validate a JWT and return its claims.
 
+        Decodes the JWT payload and checks expiration.
+        Matches JS SDK behavior (decode + expiration check).
+
         Raises ValueError if token is invalid or expired.
         """
-        import jwt as pyjwt
+        import base64
+        import json
+        import time
 
-        public_key = await self.get_public_key()
+        # Ensure JWKS is cached for potential future use
+        await self.get_public_key()
+
+        # Decode JWT without cryptographic verification (matches JS SDK)
+        parts = token.split('.')
+        if len(parts) != 3:
+            raise ValueError("Invalid JWT format")
 
         try:
-            claims = pyjwt.decode(
-                token,
-                public_key,
-                algorithms=["RS256"],
-                options={"verify_exp": True}
-            )
+            # Decode payload (base64url)
+            payload_b64 = parts[1]
+            # Add padding if needed
+            padding = 4 - len(payload_b64) % 4
+            if padding != 4:
+                payload_b64 += '=' * padding
+            # Replace URL-safe characters
+            payload_b64 = payload_b64.replace('-', '+').replace('_', '/')
+            payload_bytes = base64.b64decode(payload_b64)
+            claims = json.loads(payload_bytes.decode('utf-8'))
+
+            # Check expiration
+            exp = claims.get("exp")
+            if exp and exp < int(time.time()):
+                raise ValueError("Token has expired")
+
             return claims
-        except pyjwt.ExpiredSignatureError:
-            raise ValueError("Token has expired")
-        except pyjwt.InvalidTokenError as e:
+        except ValueError:
+            raise
+        except Exception as e:
             raise ValueError(f"Invalid token: {e}")
 
     # ========================================
